Stan Math Library: stan/math/fwd/mat/fun/trace_quad_form.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

trace_quad_form.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_MAT_FUN_TRACE_QUAD_FORM_HPP
2 #define STAN_MATH_FWD_MAT_FUN_TRACE_QUAD_FORM_HPP
3
4 #include <boost/type_traits.hpp>
5 #include <stan/math/prim/mat/err/check_multiplicable.hpp>
6 #include <stan/math/prim/mat/err/check_square.hpp>
7 #include <stan/math/fwd/mat/fun/multiply.hpp>
8 #include <stan/math/prim/mat/fun/multiply.hpp>
9 #include <stan/math/prim/mat/fun/transpose.hpp>
10 #include <stan/math/prim/mat/fun/trace.hpp>
11 #include <stan/math/fwd/core.hpp>
12
13 namespace stan {
14 namespace math {
15
16 template<int RA, int CA, int RB, int CB, typename T>
17 inline fvar<T>
18 trace_quad_form(const Eigen::Matrix<fvar<T>, RA, CA> &A,
19 const Eigen::Matrix<fvar<T>, RB, CB> &B) {
20 check_square("trace_quad_form", "A", A);
21 check_multiplicable("trace_quad_form",
22 "A", A,
23 "B", B);
24 return trace(multiply(transpose(B),
25 multiply(A, B)));
26 }
27
28 template<int RA, int CA, int RB, int CB, typename T>
29 inline fvar<T>
30 trace_quad_form(const Eigen::Matrix<fvar<T>, RA, CA> &A,
31 const Eigen::Matrix<double, RB, CB> &B) {
32 check_square("trace_quad_form", "A", A);
33 check_multiplicable("trace_quad_form",
34 "A", A,
35 "B", B);
36 return trace(multiply(transpose(B),
37 multiply(A, B)));
38 }
39
40 template<int RA, int CA, int RB, int CB, typename T>
41 inline fvar<T>
42 trace_quad_form(const Eigen::Matrix<double, RA, CA> &A,
43 const Eigen::Matrix<fvar<T>, RB, CB> &B) {
44 check_square("trace_quad_form", "A", A);
45 check_multiplicable("trace_quad_form",
46 "A", A,
47 "B", B);
48 return trace(multiply(transpose(B),
49 multiply(A, B)));
50 }
51 }
52 }
53
54 #endif
55
multiply.hpp
core.hpp
check_multiplicable.hpp
stan::math::trace_quad_form
fvar< T > trace_quad_form(const Eigen::Matrix< fvar< T >, RA, CA > &A, const Eigen::Matrix< fvar< T >, RB, CB > &B)
Definition: trace_quad_form.hpp:18
stan
Definition: log_sum_exp.hpp:8
stan::math::multiply
Eigen::Matrix< fvar< T >, R1, C1 > multiply(const Eigen::Matrix< fvar< T >, R1, C1 > &m, const fvar< T > &c)
Definition: multiply.hpp:21
multiply.hpp
transpose.hpp
trace.hpp
stan::math::check_multiplicable
bool check_multiplicable(const char *function, const char *name1, const T1 &y1, const char *name2, const T2 &y2)
Return true if the matrices can be multiplied.
Definition: check_multiplicable.hpp:33
stan::math::trace
T trace(const Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > &m)
Returns the trace of the specified matrix.
Definition: trace.hpp:20
stan::math::transpose
Eigen::Matrix< T, C, R > transpose(const Eigen::Matrix< T, R, C > &m)
Definition: transpose.hpp:12
stan::math::check_square
bool check_square(const char *function, const char *name, const Eigen::Matrix< T_y, Eigen::Dynamic, Eigen::Dynamic > &y)
Return true if the specified matrix is square.
Definition: check_square.hpp:28
stan::math::fvar
Definition: fvar.hpp:13
check_square.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.